Crate base64url

Crate base64url 

Implementation of the encode and decode operations on base64url (as defined in IETF RFC 4648) String. The encoded string restricted to containing the 2^6 UTF-8 code points without padding.

In general, we use - and _ instead of + and /, without paddings.

Functions

decode
decode takes in a string and tries to decode it into a Vector of bytes. It returns a base64::DecodeError if string is not valid Base64URL.
encode
encode takes in a slice of bytes and returns the bytes encoded as a base64url String.